You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@river.apache.org by pe...@apache.org on 2013/01/02 06:21:08 UTC

svn commit: r1427655 [14/35] - in /river/jtsk/skunk/qa_refactor/trunk/qa: ./ doc/ src/com/sun/jini/qa/harness/ src/com/sun/jini/test/impl/discoverymanager/ src/com/sun/jini/test/impl/discoveryproviders/ src/com/sun/jini/test/impl/end2end/e2etest/ src/c...

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/MailboxTestBase.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/MailboxTestBase.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/MailboxTestBase.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/MailboxTestBase.java Wed Jan  2 05:20:52 2013
@@ -26,6 +26,7 @@ import java.rmi.RemoteException;
 
 
 import com.sun.jini.constants.TimeConstants;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.test.share.TestBase;
 import net.jini.config.Configuration;
@@ -44,7 +45,7 @@ import net.jini.core.lease.LeaseDeniedEx
 
 
 
-public abstract class MailboxTestBase extends TestBase {
+public abstract class MailboxTestBase extends TestBase implements Test {
 
     protected static final String MAILBOX_PROPERTY_NAME = "com.sun.jini.test.impl.mercury.serviceInterface";    
     protected static final String MAILBOX_IF_NAME = EventMailbox.class.getName();

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/MercuryProxyEqualityTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/MercuryProxyEqualityTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/AddRenewRemoveTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/AddRenewRemoveTest.java Wed Jan  2 05:20:52 2013
@@ -21,6 +21,7 @@ import java.util.logging.Level;
 
 // Test harness specific classes
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 
 import net.jini.core.lease.Lease;
@@ -35,7 +36,7 @@ import com.sun.jini.test.share.TestBase;
  * Test creates a lease, places it in a lease renewal set, waits for 
  * to be renewed a designated number of times and then removes it.
  */
-public class AddRenewRemoveTest extends TestBase {
+public class AddRenewRemoveTest extends TestBase implements Test {
     /** Ammount of slop we are willing to tolerate around renewals */
     private long slop;
 
@@ -51,9 +52,10 @@ public class AddRenewRemoveTest extends 
     /** Should we try shuting down the service under test? */
     private boolean tryShutdown;
 
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	this.parse();
+        return this;
     }
 
     /**

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/BaseOwner.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/BaseOwner.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/BaseOwner.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/BaseOwner.java Wed Jan  2 05:20:52 2013
@@ -35,10 +35,8 @@ import java.util.logging.Logger;
  */
 abstract public class BaseOwner extends LeaseOwner {
 
-    protected static Logger logger = Logger.getLogger("com.sun.jini.qa.harness.test");
-
     /** String to be returned by <code>didPass</code> */
-    protected String rslt = null;
+    volatile protected String rslt = null;
 
     /** Max time we are will to grant on a renewal request */
     final private long maxExtension;
@@ -53,16 +51,16 @@ abstract public class BaseOwner extends 
     final protected long slop;
 
     /** Current expiration time of lease */
-    protected long expiration;
+    volatile protected long expiration;
 
     /** Time of last renewal */
-    private long lastRenewal;
+    volatile private long lastRenewal;
 
     /** Object to notify if we fail */
-    private Object notifyOnFailure;
+    final private Object notifyOnFailure;
 
     /** In the context of a batch renew call the current time */
-    protected long now;
+    volatile protected long now;
 
     /** 
      * Simple constructor 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/BatchRenewTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/BatchRenewTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/BatchRenewTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/BatchRenewTest.java Wed Jan  2 05:20:52 2013
@@ -21,6 +21,7 @@ import java.util.logging.Level;
 
 // Test harness specific classes
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 
 import java.rmi.RemoteException;
@@ -39,7 +40,7 @@ import com.sun.jini.test.share.TestBase;
  * some time and makes sure that only the leases that should
  * have expired expire.
  */
-public class BatchRenewTest extends TestBase {
+public class BatchRenewTest extends TestBase implements Test {
     /** Ammount of slop we are willing to tolerate around renewals */
     private long slop;
 
@@ -49,9 +50,10 @@ public class BatchRenewTest extends Test
     /** Array of LeaseBackEndImpl */
     private LeaseBackEndImpl homes[] = new LeaseBackEndImpl[5];
 
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	this.parse();
+        return this;
     }
 
     /**

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/ExpiredLeaseTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/ExpiredLeaseTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/ExpiredLeaseTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/ExpiredLeaseTest.java Wed Jan  2 05:20:52 2013
@@ -40,6 +40,7 @@ import net.jini.lease.RenewalFailureEven
 import com.sun.jini.test.share.TestBase;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /** 
  * Test that registers for renewal failure events, creates an expired
@@ -50,7 +51,7 @@ import com.sun.jini.qa.harness.QAConfig;
  * that will expire after the sever is restarted and check to see if 
  * an event is delvered for that lease as well
  */
-public class ExpiredLeaseTest extends TestBase {
+public class ExpiredLeaseTest extends TestBase implements Test {
 
     /** Should we try shuting down the service under test? */
     private boolean tryShutdown;
@@ -58,9 +59,10 @@ public class ExpiredLeaseTest extends Te
     /** How long should we wait before giving up on event delevery */
     private long eventWait;
 
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	this.parse();
+        return this;
     }
 
     /**
@@ -127,7 +129,7 @@ public class ExpiredLeaseTest extends Te
 
 	logger.log(Level.INFO, "First half of test passed, ");
 
-	Admin admin = manager.getAdmin(lrs);
+	Admin admin = getManager().getAdmin(lrs);
 	if (admin instanceof ActivatableServiceStarterAdmin) {
 	    logger.log(Level.INFO, "trying second half");
 	    final Lease second = LocalLease.getDestructingLocalLease(Lease.FOREVER,

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/GetLeasesTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/GetLeasesTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/GetLeasesTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/GetLeasesTest.java Wed Jan  2 05:20:52 2013
@@ -22,6 +22,7 @@ import java.util.logging.Level;
 // Test harness specific classes
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.Set;
 import java.util.HashSet;
@@ -45,7 +46,7 @@ import com.sun.jini.test.share.TestBase;
  * still in the set and then calls getLeases again to ensure that all the other
  * leases are still present.
  */
-public class GetLeasesTest extends TestBase {
+public class GetLeasesTest extends TestBase implements Test {
 
     /** Membership duration for short lease */    
     private long membershipDuration;
@@ -56,9 +57,10 @@ public class GetLeasesTest extends TestB
     /** The set of leases we think are in the renewal set */
     final private Set leases = new HashSet();
 
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	this.parse();
+        return this;
     }
 
     /**

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/LeaseBackEndImpl.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/LeaseBackEndImpl.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/LeaseBackEndImpl.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/LeaseBackEndImpl.java Wed Jan  2 05:20:52 2013
@@ -32,7 +32,7 @@ import net.jini.config.ConfigurationExce
 import net.jini.export.Exporter;
 import java.io.Serializable;
 
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
 import com.sun.jini.qa.harness.QAConfig;
 
 import net.jini.export.Exporter;

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/LeaseExpirationTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/LeaseExpirationTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/LeaseExpirationTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/LeaseExpirationTest.java Wed Jan  2 05:20:52 2013
@@ -23,6 +23,7 @@ import java.util.logging.Level;
 import java.io.PrintWriter;
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.rmi.MarshalledObject;
 import java.rmi.RemoteException;
@@ -43,7 +44,7 @@ import com.sun.jini.test.share.TestBase;
  * the set's lease expire.  Fails if the leases it places in the set
  * are renewed after the set expires.
  */
-public class LeaseExpirationTest extends TestBase {
+public class LeaseExpirationTest extends TestBase implements Test {
 
     /** Ammount of slop we are willing to tolerate around renewals */
     private long slop;
@@ -78,9 +79,10 @@ public class LeaseExpirationTest extends
     /** The current expiration time of the set's lease */
     private long setLeaseCurrentExpiration;
 
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	this.parse();
+        return this;
     }
 
     /**

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/LeaseOwner.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/LeaseOwner.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/LeaseOwner.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/LeaseOwner.java Wed Jan  2 05:20:52 2013
@@ -17,7 +17,6 @@
  */
 package com.sun.jini.test.impl.norm;
 
-import net.jini.core.lease.Lease;
 import net.jini.core.lease.LeaseDeniedException;
 import net.jini.core.lease.UnknownLeaseException;
 
@@ -29,7 +28,7 @@ import java.util.logging.Logger;
  */
 public abstract class LeaseOwner {
 
-    protected static Logger logger = Logger.getLogger("com.sun.jini.qa.harness.test");
+    protected final static Logger logger = Logger.getLogger("com.sun.jini.qa.harness.test");
 
     /**
      * The renewal service is renewing the given lease. 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/LocalLease.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/LocalLease.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/LocalLease.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/LocalLease.java Wed Jan  2 05:20:52 2013
@@ -43,7 +43,7 @@ import net.jini.security.TrustVerifier;
 import net.jini.core.constraint.RemoteMethodControl;
 import net.jini.core.constraint.MethodConstraints;
 
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
 import com.sun.jini.qa.harness.QAConfig;
 
 /**

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/OneExpireOneNotTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/OneExpireOneNotTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/OneExpireOneNotTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/OneExpireOneNotTest.java Wed Jan  2 05:20:52 2013
@@ -32,7 +32,8 @@ import com.sun.jini.qa.harness.TestExcep
 import com.sun.jini.qa.harness.QAConfig;
 
 import com.sun.jini.qa.harness.QAConfig;
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
+import com.sun.jini.qa.harness.Test;
 
 import com.sun.jini.test.share.LeaseBackEndImpl;
 import com.sun.jini.test.share.LeaseOwner;
@@ -48,7 +49,7 @@ import com.sun.jini.test.share.TrackingO
  * leases in the expired set don't get renewed after the set expires,
  * and that the other leases don't expire.
  */
-public class OneExpireOneNotTest extends QATest {
+public class OneExpireOneNotTest extends QATestEnvironment implements Test {
     /** The service under test */
     private LeaseRenewalService lrs;
 
@@ -71,10 +72,10 @@ public class OneExpireOneNotTest extends
     /**
      * Sets up the testing environment.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
 
        // mandatory call to parent
-       super.setup(sysConfig);
+       super.construct(sysConfig);
 	
        // output the name of this test
        logger.log(Level.FINE, "Test Name = " + this.getClass().getName());
@@ -103,7 +104,8 @@ public class OneExpireOneNotTest extends
 
        // Get an LRS
        logger.log(Level.FINE, "Getting a " + SERVICE_NAME);
-       lrs = (LeaseRenewalService)manager.startService(SERVICE_NAME);
+       lrs = (LeaseRenewalService)getManager().startService(SERVICE_NAME);
+       return this;
     }
 
     public void run() throws Exception {

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/RemoteListener.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/RemoteListener.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/RemoteListener.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/RemoteListener.java Wed Jan  2 05:20:52 2013
@@ -34,7 +34,7 @@ import com.sun.jini.proxy.BasicProxyTrus
 import java.io.ObjectStreamException;
 import java.io.Serializable;
 
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
 import com.sun.jini.qa.harness.QAConfig;
 
 /**

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/RemoveExactlyOneTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/RemoveExactlyOneTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/RemoveExactlyOneTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/RemoveExactlyOneTest.java Wed Jan  2 05:20:52 2013
@@ -21,6 +21,7 @@ import java.util.logging.Level;
 
 // Test harness specific classes
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 
 import java.lang.reflect.Constructor;
@@ -49,7 +50,7 @@ import com.sun.jini.test.share.TestBase;
  * events are recived (the one with the listener that did not throw
  * an exception) and fail otherwise
  */
-public class RemoveExactlyOneTest extends TestBase {
+public class RemoveExactlyOneTest extends TestBase implements Test {
     /** Total time we are willing to wait for events to happen */
     private long eventWaitFor;
 
@@ -88,9 +89,10 @@ public class RemoveExactlyOneTest extend
      */
     private long leaseID;
 	
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	this.parse();
+        return this;
     }
 
     /**

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/RenewAtTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/RenewAtTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/RenewAtTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/RenewAtTest.java Wed Jan  2 05:20:52 2013
@@ -21,6 +21,7 @@ import java.util.logging.Level;
 
 // Test harness specific classes
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 
 import net.jini.core.lease.Lease;
@@ -37,16 +38,17 @@ import com.sun.jini.test.share.TestBase;
  * some time and makes sure that only the leases that should
  * have expired expire.
  */
-public class RenewAtTest extends TestBase {
+public class RenewAtTest extends TestBase implements Test {
     /** Ammount of slop we are willing to tolerate around renewals */
     private long slop;
 
     /** Should we try shuting down the service under test? */
     private boolean tryShutdown;
 
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	this.parse();
+        return this;
     }
 
     /**

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/RenewalFailureTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/RenewalFailureTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/RenewalFailureTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/RenewalFailureTest.java Wed Jan  2 05:20:52 2013
@@ -21,6 +21,7 @@ import java.util.logging.Level;
 
 // Test harness specific classes
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 
 import java.io.PrintWriter;
@@ -54,7 +55,7 @@ import com.sun.jini.test.share.TestBase;
  * the appropriate events get generated, and that the leases are removed
  * from the set.
  */
-public class RenewalFailureTest extends TestBase {
+public class RenewalFailureTest extends TestBase implements Test {
     /** Wiggle room for various timing parameters */
     final static private long slop = 10000;
 
@@ -73,9 +74,10 @@ public class RenewalFailureTest extends 
     /** Should we try shuting down the service under test? */
     private boolean tryShutdown;
 
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	this.parse();
+        return this;
     }
 
     /**

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/UseRenewalServiceLeaseRemoveTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/UseRenewalServiceLeaseRemoveTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/UseRenewalServiceLeaseRemoveTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/UseRenewalServiceLeaseRemoveTest.java Wed Jan  2 05:20:52 2013
@@ -21,6 +21,7 @@ import java.util.logging.Level;
 
 // Test harness specific classes
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 
 import java.rmi.NoSuchObjectException;
@@ -56,9 +57,10 @@ public class UseRenewalServiceLeaseRemov
      */
     private boolean firstTime = true;
 
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	this.parse();
+        return this;
     }
 
     protected void parse() throws Exception {

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/UseRenewalServiceLeaseTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/UseRenewalServiceLeaseTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/UseRenewalServiceLeaseTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/UseRenewalServiceLeaseTest.java Wed Jan  2 05:20:52 2013
@@ -21,6 +21,7 @@ import java.util.logging.Level;
 
 // Test harness specific classes
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 
 import java.rmi.NoSuchObjectException;
@@ -56,9 +57,10 @@ public class UseRenewalServiceLeaseTest 
      */
     private long bundle = 0;
 
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	this.parse();
+        return this;
     }
 
     protected void parse() throws Exception {

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/outrigger/admin/DestroyTestMahalo.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/outrigger/admin/DestroyTestMahalo.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/outrigger/admin/DestroyTestMahalo.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/outrigger/admin/DestroyTestMahalo.java Wed Jan  2 05:20:52 2013
@@ -21,6 +21,7 @@ package com.sun.jini.test.impl.outrigger
 import com.sun.jini.test.share.DestroyTest;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 
@@ -29,10 +30,11 @@ import java.util.logging.Level;
  */
 public class DestroyTestMahalo extends DestroyTest {
 
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
 
         // Log out test parameters.
         logger.log(Level.INFO, "checkPersistenceDir = " + checkDir);
+        return this;
     }
 }

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/outrigger/admin/DestroyTestOutrigger.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/outrigger/admin/DestroyTestOutrigger.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/outrigger/admin/DestroyTestOutrigger.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/outrigger/admin/DestroyTestOutrigger.java Wed Jan  2 05:20:52 2013
@@ -21,6 +21,7 @@ package com.sun.jini.test.impl.outrigger
 import com.sun.jini.test.share.DestroyTest;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import java.util.logging.Level;
 import java.util.logging.Logger;
 
@@ -30,10 +31,11 @@ import java.util.logging.Logger;
  */
 public class DestroyTestOutrigger extends DestroyTest {
 
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
 
         // Log out test parameters.
         logger.log(Level.INFO, "checkPersistenceDir = " + checkDir);
+        return this;
     }
 }

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/outrigger/admin/IdenticalAdminIteratorTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/outrigger/admin/IdenticalAdminIteratorTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/outrigger/admin/IdenticalAdminIteratorTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/outrigger/admin/IdenticalAdminIteratorTest.java Wed Jan  2 05:20:52 2013
@@ -33,6 +33,7 @@ import com.sun.jini.outrigger.AdminItera
 
 // Test harness specific classes
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 
 // Shared classes
@@ -43,7 +44,7 @@ import com.sun.jini.test.share.Uninteres
  * Write a large number of identical entries into the space and then
  * tryes to delete all of them using the AdminIterator.
  */
-public class IdenticalAdminIteratorTest extends TestBase {
+public class IdenticalAdminIteratorTest extends TestBase implements Test {
 
     /** Number of entries to write */
     private int numberToWrite = 1000;
@@ -57,9 +58,10 @@ public class IdenticalAdminIteratorTest 
     /** True if we are going to retry remote exceptions on iterator opts */
     private boolean retry = false;
 
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
         this.parse();
+        return this;
     }
 
     /**

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/outrigger/admin/LookupAttributeAdminTestOutrigger.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/outrigger/admin/LookupAttributeAdminTestOutrigger.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/outrigger/admin/LookupAttributeAdminTestOutrigger.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/outrigger/admin/LookupAttributeAdminTestOutrigger.java Wed Jan  2 05:20:52 2013
@@ -21,6 +21,7 @@ package com.sun.jini.test.impl.outrigger
 import com.sun.jini.test.share.LookupAttributeAdminTest;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import java.util.logging.Level;
 import java.util.logging.Logger;
 
@@ -31,11 +32,12 @@ import java.util.logging.Logger;
 public class LookupAttributeAdminTestOutrigger
         extends LookupAttributeAdminTest {
 
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
 
         // Log out test parameters.
         logger.log(Level.INFO, "tryShutdown = " + tryShutdown);
         logger.log(Level.INFO, "restart_wait = " + minPostKillWait);
+        return this;
     }
 }

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/outrigger/admin/LookupGroupAdminTestOutrigger.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/outrigger/admin/LookupGroupAdminTestOutrigger.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/outrigger/admin/LookupGroupAdminTestOutrigger.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/outrigger/admin/LookupGroupAdminTestOutrigger.java Wed Jan  2 05:20:52 2013
@@ -21,6 +21,7 @@ package com.sun.jini.test.impl.outrigger
 import com.sun.jini.test.share.LookupGroupAdminTest;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import java.util.logging.Level;
 import java.util.logging.Logger;
 
@@ -30,11 +31,12 @@ import java.util.logging.Logger;
  */
 public class LookupGroupAdminTestOutrigger extends LookupGroupAdminTest {
 
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
 
         // Log out test parameters.
         logger.log(Level.INFO, "tryShutdown = " + tryShutdown);
         logger.log(Level.INFO, "restart_wait = " + minPostKillWait);
+        return this;
     }
 }

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/outrigger/admin/LookupLocatorAdminTestOutrigger.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/outrigger/admin/LookupLocatorAdminTestOutrigger.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/outrigger/admin/LookupLocatorAdminTestOutrigger.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/outrigger/admin/LookupLocatorAdminTestOutrigger.java Wed Jan  2 05:20:52 2013
@@ -21,6 +21,7 @@ package com.sun.jini.test.impl.outrigger
 import com.sun.jini.test.share.LookupLocatorAdminTest;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import java.util.logging.Level;
 import java.util.logging.Logger;
 
@@ -30,11 +31,12 @@ import java.util.logging.Logger;
  */
 public class LookupLocatorAdminTestOutrigger extends LookupLocatorAdminTest {
 
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
 
         // Log out test parameters.
         logger.log(Level.INFO, "tryShutdown = " + tryShutdown);
         logger.log(Level.INFO, "restart_wait = " + minPostKillWait);
+        return this;
     }
 }

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/outrigger/admin/SimpleAdminTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/outrigger/admin/SimpleAdminTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/outrigger/admin/SimpleAdminTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/outrigger/admin/SimpleAdminTest.java Wed Jan  2 05:20:52 2013
@@ -35,6 +35,7 @@ import com.sun.jini.qa.harness.TestExcep
 import com.sun.jini.qa.harness.QAConfig;
 
 // Shared classes
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.test.share.TestBase;
 import com.sun.jini.test.share.UninterestingEntry;
 
@@ -44,13 +45,14 @@ import com.sun.jini.test.share.Uninteres
  * test the contence() method as this is exercies by the
  * AdminIteratorTest in the matching package.
  */
-public class SimpleAdminTest extends TestBase {
+public class SimpleAdminTest extends TestBase implements Test {
     private boolean activatable;
     private int numRestarts;
 
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
         this.parse();
+        return this;
     }
 
     /**

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/outrigger/api/AbstractEntryTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/outrigger/api/AbstractEntryTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/outrigger/api/AbstractEntryTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/outrigger/api/AbstractEntryTest.java Wed Jan  2 05:20:52 2013
@@ -32,15 +32,16 @@ import java.util.Iterator;
 
 // Test harness specific classes
 import com.sun.jini.qa.harness.TestException;
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 
 /**
  * Test to make sure that extended AbstractEntry objects and
  * implemented Entry objects work as specified.
  */
-public class AbstractEntryTest extends QATest {
+public class AbstractEntryTest extends QATestEnvironment implements Test {
     private int failed = 0; // count of failed tests
     private boolean verbose;
 
@@ -92,9 +93,10 @@ public class AbstractEntryTest extends Q
         }
     }
 
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
         this.parse();
+        return this;
     }
 
     /**

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/outrigger/api/InterruptTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/outrigger/api/InterruptTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/outrigger/api/InterruptTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/outrigger/api/InterruptTest.java Wed Jan  2 05:20:52 2013
@@ -29,18 +29,19 @@ import net.jini.admin.Administrable;
 // Test harness specific classes
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.qa.harness.QAConfig;
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
 
 
 
 // Shared classes
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.test.share.TestBase;
 
 
 /**
  * Test to make sure blocking reads can be interrupted
  */
-public class InterruptTest extends TestBase {
+public class InterruptTest extends TestBase implements Test {
 
 
     private class ReadThread extends Thread {
@@ -63,9 +64,10 @@ public class InterruptTest extends TestB
         }
     }
 
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
         super.parse();
+        return this;
     }
 
     public void run() throws Exception {

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/outrigger/javaspace05/MutatingContentsTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/outrigger/javaspace05/MutatingContentsTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/outrigger/javaspace05/MutatingContentsTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/outrigger/javaspace05/MutatingContentsTest.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.impl.outrigger.javaspace05;
 
+import com.sun.jini.qa.harness.Test;
 import java.util.logging.Level;
 
 // Test harness specific classes
@@ -53,7 +54,7 @@ import com.sun.jini.test.share.TestBase;
  * expected entries come back - making allowances for entries that
  * were added and removed during the course of the iteration.  
  */
-public class MutatingContentsTest extends TestBase {
+public class MutatingContentsTest extends TestBase implements Test {
     final private static String configNameBase = 
 	"com.sun.jini.test.impl.outrigger.javaspace05.MutatingContentsTest.";
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/outrigger/javaspace05/StableContentsTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/outrigger/javaspace05/StableContentsTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/outrigger/javaspace05/StableContentsTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/outrigger/javaspace05/StableContentsTest.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.impl.outrigger.javaspace05;
 
+import com.sun.jini.qa.harness.Test;
 import java.util.logging.Level;
 
 // Test harness specific classes
@@ -49,7 +50,7 @@ import com.sun.jini.test.share.TestBase;
  * templates. Each trail makes sure that all of the expected entries
  * and only the expected entries come back.
  */
-public class StableContentsTest extends TestBase {
+public class StableContentsTest extends TestBase implements Test {
     final private static String configNameBase = 
 	"com.sun.jini.test.impl.outrigger.javaspace05.StableContentsTest.";
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/outrigger/leasing/LeaseGrantTestBase.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/outrigger/leasing/LeaseGrantTestBase.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/outrigger/leasing/LeaseGrantTestBase.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/outrigger/leasing/LeaseGrantTestBase.java Wed Jan  2 05:20:52 2013
@@ -31,6 +31,7 @@ import com.sun.jini.qa.harness.TestExcep
 import com.sun.jini.qa.harness.QAConfig;
 
 // Shared classes
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.test.share.TestBase;
 
 
@@ -38,7 +39,7 @@ import com.sun.jini.test.share.TestBase;
  * Base class for tests which grab a lease and make sure the returned lease
  * meets give constraints.
  */
-public abstract class LeaseGrantTestBase extends TestBase {
+public abstract class LeaseGrantTestBase extends TestBase implements Test {
 
     /**
      * If true then the tests expects leases to granted
@@ -165,9 +166,10 @@ public abstract class LeaseGrantTestBase
         }
     }
 
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
         this.parse();
+        return this;
     }
 
     /**
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/MercuryProxyEqualityTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/MercuryProxyEqualityTest.java Wed Jan  2 05:20:52 2013
@@ -28,6 +28,7 @@ import com.sun.jini.qa.harness.QAConfig;
 import com.sun.jini.qa.harness.TestException;
 
 import com.sun.jini.constants.TimeConstants;
+import com.sun.jini.qa.harness.Test;
 
 import net.jini.event.EventMailbox;
 import net.jini.event.MailboxRegistration;
@@ -155,13 +156,14 @@ public class MercuryProxyEqualityTest ex
     }
 
     /**
      * Invoke parent's setup and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	parse();
+        return this;
     }
 
     private static boolean proxiesEqual(Object a, Object b) {
@@ -155,13 +156,14 @@ public class MercuryProxyEqualityTest ex
 
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullInterOpTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullInterOpTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullInterOpTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullInterOpTest.java Wed Jan  2 05:20:52 2013
@@ -36,6 +36,7 @@ import net.jini.space.JavaSpace;
 
 import com.sun.jini.qa.harness.QAConfig;
 import com.sun.jini.constants.TimeConstants;
+import com.sun.jini.qa.harness.Test;
 
 public class PullInterOpTest extends EMSTestBase implements TimeConstants {
 
@@ -68,7 +69,7 @@ public class PullInterOpTest extends EMS
 	addLease(getPullMailboxLease(mr), false);
 	
 	// Create "listener" to collect events for this test
-	TestPullListener tpl = TestUtils.createPullListener(manager);
+	TestPullListener tpl = TestUtils.createPullListener(getManager());
 
 	logger.log(Level.INFO, "Getting pull mailbox listener");
 	RemoteEventListener mbRel = getPullMailboxListener(mr);
@@ -124,12 +125,13 @@ public class PullInterOpTest extends EMS
     }
 
     /**
      * Invoke parent's setup and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	parse();
+        return this;
     }
 }
@@ -124,12 +125,13 @@ public class PullInterOpTest extends EMS
 
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullListenerRecoveryTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullListenerRecoveryTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullListenerRecoveryTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullListenerRecoveryTest.java Wed Jan  2 05:20:52 2013
@@ -38,6 +38,7 @@ import com.sun.jini.test.impl.mercury.Te
 import com.sun.jini.test.impl.mercury.TestGenerator;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 
 public class PullListenerRecoveryTest 
@@ -74,7 +75,7 @@ public class PullListenerRecoveryTest 
 
 	// Create an event generator and pass it the
 	// mailbox's remote event listener.
-	TestGenerator myGen = TestUtils.createGenerator(manager);
+	TestGenerator myGen = TestUtils.createGenerator(getManager());
 	logger.log(Level.FINEST, 
 	    "Test generator class tree" 
 	    + getClassLoaderTree(myGen.getClass().getClassLoader()));
@@ -86,7 +87,7 @@ public class PullListenerRecoveryTest 
 	Lease tgl = evtReg.getLease();
 	checkLease(tgl, DURATION1); 
 
-	TestPullListener goodListener = TestUtils.createPullListener(manager);
+	TestPullListener goodListener = TestUtils.createPullListener(getManager());
 	int goodCount = 0;
 
 	// Generate some events 
@@ -150,12 +151,13 @@ public class PullListenerRecoveryTest 
 	}
     }
     /**
      * Invoke parent's setup and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	parse();
+        return this;
     }
 }
@@ -150,12 +151,13 @@ public class PullListenerRecoveryTest 
     }
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullMercuryProxyEqualityTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullMercuryProxyEqualityTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullMercuryProxyEqualityTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullMercuryProxyEqualityTest.java Wed Jan  2 05:20:52 2013
@@ -28,6 +28,7 @@ import com.sun.jini.qa.harness.QAConfig;
 import com.sun.jini.qa.harness.TestException;
 
 import com.sun.jini.constants.TimeConstants;
+import com.sun.jini.qa.harness.Test;
 
 import net.jini.event.PullEventMailbox;
 import net.jini.event.MailboxPullRegistration;
@@ -155,13 +156,14 @@ public class PullMercuryProxyEqualityTes
     }
 
     /**
      * Invoke parent's setup and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	parse();
+        return this;
     }
 
     private static boolean proxiesEqual(Object a, Object b) {
@@ -155,13 +156,14 @@ public class PullMercuryProxyEqualityTes
 
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullRegistrationIFTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullRegistrationIFTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullRegistrationIFTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullRegistrationIFTest.java Wed Jan  2 05:20:52 2013
@@ -39,6 +39,7 @@ import net.jini.core.event.RemoteEvent;
 import net.jini.core.event.UnknownEventException;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 public class PullRegistrationIFTest extends MailboxTestBase 
     implements TimeConstants 
@@ -74,7 +75,7 @@ public class PullRegistrationIFTest exte
         logger.log(Level.INFO, "Unable to resubmit listener reference -- OK");
         
         // create new listener object
-        rel =  TestUtils.createListener(manager);
+        rel =  TestUtils.createListener(getManager());
         logger.log(Level.INFO, "Got test listener reference: {0}", rel);
         
         // submit listener
@@ -124,12 +125,13 @@ public class PullRegistrationIFTest exte
     }
 
     /**
      * Invoke parent's setup and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	parse();
+        return this;
     }
 }
@@ -124,12 +125,13 @@ public class PullRegistrationIFTest exte
 
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullTimeoutTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullTimeoutTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullTimeoutTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullTimeoutTest.java Wed Jan  2 05:20:52 2013
@@ -45,6 +45,7 @@ import com.sun.jini.test.impl.mercury.Te
 import com.sun.jini.test.impl.mercury.TestGenerator;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 
 public class PullTimeoutTest 
@@ -130,7 +131,7 @@ public class PullTimeoutTest 
 
 	// Create an event generator and pass it the
 	// mailbox's remote event listener.
-	TestGenerator myGen = TestUtils.createGenerator(manager);
+	TestGenerator myGen = TestUtils.createGenerator(getManager());
 	logger.log(Level.FINEST, 
 	    "Test generator class tree" 
 	    + getClassLoaderTree(myGen.getClass().getClassLoader()));
@@ -144,7 +145,7 @@ public class PullTimeoutTest 
 
 	// Create another event generator and pass it the
 	// mailbox's remote event listener.
-	TestGenerator myGen2 = TestUtils.createGenerator(manager);
+	TestGenerator myGen2 = TestUtils.createGenerator(getManager());
 	logger.log(Level.FINEST, 
 	    "Test generator class tree" 
 	    + getClassLoaderTree(myGen2.getClass().getClassLoader()));
@@ -280,12 +281,13 @@ public class PullTimeoutTest 
             
     }
     /**
      * Invoke parent's setup and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	parse();
+        return this;
     }
 }
@@ -280,12 +281,13 @@ public class PullTimeoutTest 
     }
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullTimeoutTest2.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullTimeoutTest2.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullTimeoutTest2.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullTimeoutTest2.java Wed Jan  2 05:20:52 2013
@@ -45,6 +45,7 @@ import com.sun.jini.test.impl.mercury.Te
 import com.sun.jini.test.impl.mercury.TestGenerator;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 
 public class PullTimeoutTest2 
@@ -106,12 +107,13 @@ public class PullTimeoutTest2 
 
     }
     /**
      * Invoke parent's setup and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	parse();
+        return this;
     }
 }
@@ -106,12 +107,13 @@ public class PullTimeoutTest2 
     }
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullTimeoutTest3.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullTimeoutTest3.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullTimeoutTest3.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullTimeoutTest3.java Wed Jan  2 05:20:52 2013
@@ -46,6 +46,7 @@ import com.sun.jini.test.impl.mercury.Te
 import com.sun.jini.test.impl.mercury.TestGenerator;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 
 public class PullTimeoutTest3 
@@ -151,12 +152,13 @@ public class PullTimeoutTest3 
 
     }
     /**
      * Invoke parent's setup and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	parse();
+        return this;
     }
 }
@@ -151,12 +152,13 @@ public class PullTimeoutTest3 
     }
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullTimeoutTest4.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullTimeoutTest4.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullTimeoutTest4.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullTimeoutTest4.java Wed Jan  2 05:20:52 2013
@@ -46,6 +46,7 @@ import com.sun.jini.test.impl.mercury.Te
 import com.sun.jini.test.impl.mercury.TestGenerator;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 
 public class PullTimeoutTest4
@@ -147,12 +148,13 @@ public class PullTimeoutTest4
 
     }
     /**
      * Invoke parent's setup and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	parse();
+        return this;
     }
 }
@@ -147,12 +148,13 @@ public class PullTimeoutTest4
     }
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullTimeoutTest5.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullTimeoutTest5.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullTimeoutTest5.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullTimeoutTest5.java Wed Jan  2 05:20:52 2013
@@ -46,6 +46,7 @@ import com.sun.jini.test.impl.mercury.Te
 import com.sun.jini.test.impl.mercury.TestGenerator;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 
 public class PullTimeoutTest5
@@ -158,12 +159,13 @@ public class PullTimeoutTest5
 
     }
     /**
      * Invoke parent's setup and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	parse();
+        return this;
     }
 }
@@ -158,12 +159,13 @@ public class PullTimeoutTest5
     }
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullTimeoutTest6.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullTimeoutTest6.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullTimeoutTest6.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullTimeoutTest6.java Wed Jan  2 05:20:52 2013
@@ -46,6 +46,7 @@ import com.sun.jini.test.impl.mercury.Te
 import com.sun.jini.test.impl.mercury.TestGenerator;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 
 /* 
@@ -159,12 +160,13 @@ public class PullTimeoutTest6 
             
     }
     /**
      * Invoke parent's setup and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	parse();
+        return this;
     }
 }
@@ -159,12 +160,13 @@ public class PullTimeoutTest6 
     }
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullTimeoutTest6A.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullTimeoutTest6A.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullTimeoutTest6A.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullTimeoutTest6A.java Wed Jan  2 05:20:52 2013
@@ -46,6 +46,7 @@ import com.sun.jini.test.impl.mercury.Te
 import com.sun.jini.test.impl.mercury.TestGenerator;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 
 /* 
@@ -160,12 +161,13 @@ public class PullTimeoutTest6A 
             
     }
     /**
      * Invoke parent's setup and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	parse();
+        return this;
     }
 }
@@ -160,12 +161,13 @@ public class PullTimeoutTest6A 
     }
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullTimeoutTest6B.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullTimeoutTest6B.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullTimeoutTest6B.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullTimeoutTest6B.java Wed Jan  2 05:20:52 2013
@@ -46,6 +46,7 @@ import com.sun.jini.test.impl.mercury.Te
 import com.sun.jini.test.impl.mercury.TestGenerator;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 
 /* 
@@ -201,12 +202,13 @@ public class PullTimeoutTest6B 
         }
     }
     /**
      * Invoke parent's setup and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	parse();
+        return this;
     }
 }
@@ -201,12 +202,13 @@ public class PullTimeoutTest6B 
     }
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullUnknownEventsTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullUnknownEventsTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullUnknownEventsTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullUnknownEventsTest.java Wed Jan  2 05:20:52 2013
@@ -42,6 +42,7 @@ import com.sun.jini.test.impl.mercury.Te
 import com.sun.jini.test.impl.mercury.TestGenerator;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 
 public class PullUnknownEventsTest 
@@ -79,7 +80,7 @@ public class PullUnknownEventsTest 
 
 	// Create an event generator and pass it the
 	// mailbox's remote event listener.
-	TestGenerator myGen = TestUtils.createGenerator(manager);
+	TestGenerator myGen = TestUtils.createGenerator(getManager());
 	logger.log(Level.FINEST, 
 	    "Test generator class tree" 
 	    + getClassLoaderTree(myGen.getClass().getClassLoader()));
@@ -93,7 +94,7 @@ public class PullUnknownEventsTest 
 
 	// Create another event generator and pass it the
 	// mailbox's remote event listener.
-	TestGenerator myGen2 = TestUtils.createGenerator(manager);
+	TestGenerator myGen2 = TestUtils.createGenerator(getManager());
 	logger.log(Level.FINEST, 
 	    "Test generator class tree" 
 	    + getClassLoaderTree(myGen2.getClass().getClassLoader()));
@@ -260,12 +261,13 @@ public class PullUnknownEventsTest 
 
     }
     /**
      * Invoke parent's setup and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	parse();
+        return this;
     }
 }
@@ -260,12 +261,13 @@ public class PullUnknownEventsTest 
     }
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullUnknownEventsTest2.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullUnknownEventsTest2.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullUnknownEventsTest2.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PullUnknownEventsTest2.java Wed Jan  2 05:20:52 2013
@@ -42,6 +42,7 @@ import com.sun.jini.test.impl.mercury.Te
 import com.sun.jini.test.impl.mercury.TestGenerator;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 
 public class PullUnknownEventsTest2 
@@ -79,7 +80,7 @@ public class PullUnknownEventsTest2 
 
 	// Create an event generator and pass it the
 	// mailbox's remote event listener.
-	TestGenerator myGen = TestUtils.createGenerator(manager);
+	TestGenerator myGen = TestUtils.createGenerator(getManager());
 	logger.log(Level.FINEST, 
 	    "Test generator class tree" 
 	    + getClassLoaderTree(myGen.getClass().getClassLoader()));
@@ -93,7 +94,7 @@ public class PullUnknownEventsTest2 
 
 	// Create another event generator and pass it the
 	// mailbox's remote event listener.
-	TestGenerator myGen2 = TestUtils.createGenerator(manager);
+	TestGenerator myGen2 = TestUtils.createGenerator(getManager());
 	logger.log(Level.FINEST, 
 	    "Test generator class tree" 
 	    + getClassLoaderTree(myGen2.getClass().getClassLoader()));
@@ -183,12 +184,13 @@ public class PullUnknownEventsTest2 
 
     }
     /**
      * Invoke parent's setup and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	parse();
+        return this;
     }
 }
@@ -183,12 +184,13 @@ public class PullUnknownEventsTest2 
     }
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PushPullListenerRecoveryTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PushPullListenerRecoveryTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PushPullListenerRecoveryTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/PushPullListenerRecoveryTest.java Wed Jan  2 05:20:52 2013
@@ -40,12 +40,13 @@ import com.sun.jini.test.impl.mercury.Te
 import com.sun.jini.test.impl.mercury.TestGenerator;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 
 public class PushPullListenerRecoveryTest 
     extends EMSTestBase implements TimeConstants 
 {
-
+    
     //
     // This should be long enough to sensibly run the test.
     // If the service doesn't grant long enough leases, then
@@ -76,7 +77,7 @@ public class PushPullListenerRecoveryTes
 
 	// Create an event generator and pass it the
 	// mailbox's remote event listener.
-	TestGenerator myGen = TestUtils.createGenerator(manager);
+	TestGenerator myGen = TestUtils.createGenerator(getManager());
 	logger.log(Level.FINEST, 
 	    "Test generator class tree" 
 	    + getClassLoaderTree(myGen.getClass().getClassLoader()));
@@ -88,7 +89,7 @@ public class PushPullListenerRecoveryTes
 	Lease tgl = evtReg.getLease();
 	checkLease(tgl, DURATION1); 
 
-	TestListener goodListener = TestUtils.createListener(manager);
+	TestListener goodListener = TestUtils.createListener(getManager());
 	int goodCount = 0;
         int goodPullCount = 0;
 
@@ -235,12 +236,13 @@ public class PushPullListenerRecoveryTes
 	}
     }
     /**
      * Invoke parent's setup and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	parse();
+        return this;
     }
 }
@@ -235,12 +236,13 @@ public class PushPullListenerRecoveryTes
     }
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/RegCancelExpireShutdownTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/RegCancelExpireShutdownTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/RegCancelExpireShutdownTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/RegCancelExpireShutdownTest.java Wed Jan  2 05:20:52 2013
@@ -27,6 +27,7 @@ import com.sun.jini.qa.harness.QAConfig;
 import com.sun.jini.qa.harness.TestException;
 
 import com.sun.jini.constants.TimeConstants;
+import com.sun.jini.qa.harness.Test;
 
 import net.jini.event.EventMailbox;
 import net.jini.event.MailboxPullRegistration;
@@ -89,12 +90,13 @@ public class RegCancelExpireShutdownTest
     }
 
     /**
      * Invoke parent's setup and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	parse();
+        return this;
     }
 }
@@ -89,12 +90,13 @@ public class RegCancelExpireShutdownTest
 
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/RegCancelShutdownTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/RegCancelShutdownTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/RegCancelShutdownTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/RegCancelShutdownTest.java Wed Jan  2 05:20:52 2013
@@ -27,6 +27,7 @@ import com.sun.jini.qa.harness.QAConfig;
 import com.sun.jini.qa.harness.TestException;
 
 import com.sun.jini.constants.TimeConstants;
+import com.sun.jini.qa.harness.Test;
 
 import net.jini.event.EventMailbox;
 import net.jini.event.MailboxPullRegistration;
@@ -79,12 +80,13 @@ public class RegCancelShutdownTest exten
     }
 
     /**
      * Invoke parent's setup and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	parse();
+        return this;
     }
 }
@@ -79,12 +80,13 @@ public class RegCancelShutdownTest exten
 
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/RegCreateShutdownTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/RegCreateShutdownTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/RegCreateShutdownTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/RegCreateShutdownTest.java Wed Jan  2 05:20:52 2013
@@ -35,6 +35,7 @@ import net.jini.core.event.RemoteEvent;
 import net.jini.core.event.RemoteEventListener;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 
 public class RegCreateShutdownTest extends EMSTestBase implements TimeConstants
@@ -78,12 +79,13 @@ public class RegCreateShutdownTest exten
     }
 
     /**
      * Invoke parent's setup and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	parse();
+        return this;
     }
 }
@@ -78,12 +79,13 @@ public class RegCreateShutdownTest exten
 
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/RegDisableShutdownTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/RegDisableShutdownTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/RegDisableShutdownTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/RegDisableShutdownTest.java Wed Jan  2 05:20:52 2013
@@ -35,6 +35,7 @@ import net.jini.core.event.RemoteEvent;
 import net.jini.core.event.RemoteEventListener;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 
 public class RegDisableShutdownTest extends EMSTestBase implements TimeConstants {
@@ -84,7 +85,7 @@ public class RegDisableShutdownTest exte
 
 	// Create an event generator and pass it the
 	// mailbox's remote event listener.
-	TestGenerator myGen = TestUtils.createGenerator(manager);
+	TestGenerator myGen = TestUtils.createGenerator(getManager());
 	EventRegistration evtReg = 
 	    myGen.register(EVENT_ID,	// Event ID to use
 			   null,		// handback
@@ -94,7 +95,7 @@ public class RegDisableShutdownTest exte
 	checkLease(tgl, DURATION); 
 
 	// Create our target listener
-	TestListener listener = TestUtils.createListener(manager);
+	TestListener listener = TestUtils.createListener(getManager());
 	int evtCnt = 0;
 
 	logger.log(Level.INFO, "Generating an event" + listener);
@@ -127,12 +128,13 @@ public class RegDisableShutdownTest exte
     }
 
     /**
      * Invoke parent's setup and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	parse();
+        return this;
     }
 }
@@ -127,12 +128,13 @@ public class RegDisableShutdownTest exte
 
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/RegEnableShutdownTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/RegEnableShutdownTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/RegEnableShutdownTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/RegEnableShutdownTest.java Wed Jan  2 05:20:52 2013
@@ -18,7 +18,6 @@
 package com.sun.jini.test.impl.mercury;
 
 import java.util.logging.Level;
-
 import java.rmi.RemoteException;
 import java.rmi.NoSuchObjectException;
 import java.rmi.ServerException;
@@ -35,6 +34,7 @@ import net.jini.core.event.RemoteEvent;
 import net.jini.core.event.RemoteEventListener;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 
 public class RegEnableShutdownTest extends EMSTestBase implements TimeConstants {
@@ -86,7 +86,7 @@ public class RegEnableShutdownTest exten
 
 	// Create an event generator and pass it the
 	// mailbox's remote event listener.
-	TestGenerator myGen = TestUtils.createGenerator(manager);
+	TestGenerator myGen = TestUtils.createGenerator(getManager());
 	EventRegistration evtReg = 
 	    myGen.register(EVENT_ID,	// Event ID to use
 			   null,		// handback
@@ -96,7 +96,7 @@ public class RegEnableShutdownTest exten
 	checkLease(tgl, DURATION); 
 
 	// Create our target listener
-	TestListener listener = TestUtils.createListener(manager);
+	TestListener listener = TestUtils.createListener(getManager());
 	int evtCnt = 0;
 
 	logger.log(Level.INFO, "Generating an event from " + myGen);
@@ -127,12 +127,13 @@ public class RegEnableShutdownTest exten
     }
 
     /**
      * Invoke parent's setup and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	parse();
+        return this;
     }
 }
@@ -127,12 +127,13 @@ public class RegEnableShutdownTest exten
 
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/RegRenewExpireShutdownTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/RegRenewExpireShutdownTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/RegRenewExpireShutdownTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/RegRenewExpireShutdownTest.java Wed Jan  2 05:20:52 2013
@@ -38,6 +38,7 @@ import net.jini.core.event.RemoteEvent;
 import net.jini.core.event.RemoteEventListener;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 public class RegRenewExpireShutdownTest extends EMSTestBase 
                                         implements TimeConstants 
@@ -90,12 +91,13 @@ public class RegRenewExpireShutdownTest 
     }
 
     /**
      * Invoke parent's setup and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	parse();
+        return this;
     }
 }
@@ -90,12 +91,13 @@ public class RegRenewExpireShutdownTest 
 
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/RegRenewShutdownTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/RegRenewShutdownTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/RegRenewShutdownTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/RegRenewShutdownTest.java Wed Jan  2 05:20:52 2013
@@ -35,6 +35,7 @@ import net.jini.core.event.RemoteEvent;
 import net.jini.core.event.RemoteEventListener;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 
 public class RegRenewShutdownTest extends EMSTestBase implements TimeConstants {
@@ -84,12 +85,13 @@ public class RegRenewShutdownTest extend
     }
 
     /**
      * Invoke parent's setup and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	parse();
+        return this;
     }
 }
@@ -84,12 +85,13 @@ public class RegRenewShutdownTest extend
 
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/RegistrationIFTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/RegistrationIFTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/RegistrationIFTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/RegistrationIFTest.java Wed Jan  2 05:20:52 2013
@@ -22,7 +22,6 @@ import java.util.logging.Level;
 // Test harness specific classes
 
 import com.sun.jini.qa.harness.TestException;
-
 import java.rmi.RemoteException;
 import java.rmi.server.UnicastRemoteObject;
 
@@ -36,6 +35,7 @@ import net.jini.core.event.RemoteEvent;
 import net.jini.core.event.UnknownEventException;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 public class RegistrationIFTest extends MailboxTestBase 
     implements TimeConstants 
@@ -60,18 +60,19 @@ public class RegistrationIFTest extends 
 	} catch (IllegalArgumentException iae) {
 	}
 
-	rel =  TestUtils.createListener(manager);
+	rel =  TestUtils.createListener(getManager());
 	mr1.enableDelivery(rel);
 	mr1.disableDelivery();
     }
 
     /**
      * Invoke parent's setup and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	parse();
+        return this;
     }
 }
@@ -60,18 +60,19 @@ public class RegistrationIFTest extends 
 
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/UnknownEventRecoveryShutdownTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/UnknownEventRecoveryShutdownTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/UnknownEventRecoveryShutdownTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/UnknownEventRecoveryShutdownTest.java Wed Jan  2 05:20:52 2013
@@ -38,6 +38,7 @@ import net.jini.core.event.RemoteEventLi
 import net.jini.core.event.UnknownEventException;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 
 public class UnknownEventRecoveryShutdownTest extends EMSTestBase 
@@ -50,7 +51,6 @@ public class UnknownEventRecoveryShutdow
     // LeaseRenewalManager to keep our leases current.
     //
     private final long DURATION = 3*HOURS;
-
     private final int NUM_EVENTS = 5;
 
     private final long EVENT_ID = 1000;
@@ -91,7 +91,7 @@ public class UnknownEventRecoveryShutdow
 
 	// Create an event generator and pass it the
 	// mailbox's remote event listener.
-	TestGenerator myGen = TestUtils.createGenerator(manager);
+	TestGenerator myGen = TestUtils.createGenerator(getManager());
 	EventRegistration evtReg = 
 	    myGen.register(EVENT_ID,	// Event ID to use
 			   null,		// handback
@@ -102,7 +102,7 @@ public class UnknownEventRecoveryShutdow
 
 	// Create another event generator and pass it the
 	// mailbox's remote event listener.
-	TestGenerator myGen2 = TestUtils.createGenerator(manager);
+	TestGenerator myGen2 = TestUtils.createGenerator(getManager());
 	EventRegistration evtReg2 = 
 	    myGen2.register(EVENT_ID2,	// Event ID to use
 			    null,		// handback
@@ -112,8 +112,8 @@ public class UnknownEventRecoveryShutdow
 	checkLease(tgl2, DURATION); 
 
 	// Create two listener objects
-	TestListener goodRel = TestUtils.createListener(manager);
-	TestListener badRel = TestUtils.createUEListener(manager);
+	TestListener goodRel = TestUtils.createListener(getManager());
+	TestListener badRel = TestUtils.createUEListener(getManager());
 	int goodRelCount = 0, badRelCount = 0;
 
 	// Generate some events from both generators
@@ -236,12 +236,13 @@ public class UnknownEventRecoveryShutdow
     }
 
     /**
      * Invoke parent's setup and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	parse();
+        return this;
     }
 }
@@ -236,12 +236,13 @@ public class UnknownEventRecoveryShutdow
 
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/UnknownEventRecoveryTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/UnknownEventRecoveryTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/UnknownEventRecoveryTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/mercury/UnknownEventRecoveryTest.java Wed Jan  2 05:20:52 2013
@@ -38,6 +38,7 @@ import net.jini.core.event.RemoteEventLi
 import net.jini.core.event.UnknownEventException;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 
 public class UnknownEventRecoveryTest extends EMSTestBase 
@@ -50,7 +51,6 @@ public class UnknownEventRecoveryTest ex
     // LeaseRenewalManager to keep our leases current.
     //
     private final long DURATION = 3*HOURS;
-
     private final int NUM_EVENTS = 5;
 
     private final long EVENT_ID = 1000;
@@ -90,7 +90,7 @@ public class UnknownEventRecoveryTest ex
 
 	// Create an event generator and pass it the
 	// mailbox's remote event listener.
-	TestGenerator myGen =  TestUtils.createGenerator(manager);
+	TestGenerator myGen =  TestUtils.createGenerator(getManager());
 	EventRegistration evtReg = 
 	    myGen.register(EVENT_ID,	// Event ID to use
 			   null,		// handback
@@ -101,7 +101,7 @@ public class UnknownEventRecoveryTest ex
 
 	// Create another event generator and pass it the
 	// mailbox's remote event listener.
-	TestGenerator myGen2 = TestUtils.createGenerator(manager);
+	TestGenerator myGen2 = TestUtils.createGenerator(getManager());
 	EventRegistration evtReg2 = 
 	    myGen2.register(EVENT_ID2,	// Event ID to use
 			    null,		// handback
@@ -111,8 +111,8 @@ public class UnknownEventRecoveryTest ex
 	checkLease(tgl2, DURATION); 
 
 	// Create two listener objects
-	TestListener goodRel = TestUtils.createListener(manager);
-	TestListener badRel = TestUtils.createUEListener(manager);
+	TestListener goodRel = TestUtils.createListener(getManager());
+	TestListener badRel = TestUtils.createUEListener(getManager());
 	int goodRelCount = 0, badRelCount = 0;
 
 	// Generate some events from both generators
@@ -232,12 +232,13 @@ public class UnknownEventRecoveryTest ex
     }
 
     /**
      * Invoke parent's setup and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	parse();
+        return this;
     }
 }
@@ -232,12 +232,13 @@ public class UnknownEventRecoveryTest ex
 
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/AddRenewRemoveTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/impl/norm/AddRenewRemoveTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================